
#ifndef _C144_ds7178_
#define _C144_ds7178_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F6272_84378(EIF_REFERENCE);
extern void EIF_Minit7178(void);

#ifdef __cplusplus
}
#endif

#endif
